
/*
 * *********** WARNING **************
 * This file generated by Apache::DAV::WrapXS/0.01
 * Any changes made here will be lost
 * ***********************************
 * 1. /opt/perl5.6.1/lib/site_perl/5.6.1/ExtUtils/XSBuilder/WrapXS.pm:38
 * 2. /opt/perl5.6.1/lib/site_perl/5.6.1/ExtUtils/XSBuilder/WrapXS.pm:1898
 * 3. xsbuilder/xs_generate.pl:6
 */


#ifndef MODDAV_XS_TYPEDEFS_H
#define MODDAV_XS_TYPEDEFS_H

typedef array_header * Apache__Array;
typedef table * Apache__Table;
typedef table_entry * Apache__TableEntry;
typedef dav_datum * Apache__DAV__Datum;
typedef dav_dyn_context * Apache__DAV__DynContext;
typedef dav_dyn_hooks * Apache__DAV__DynHooks;
typedef dav_dyn_module * Apache__DAV__DynModule;
typedef dav_dyn_provider * Apache__DAV__DynProvider;
typedef dav_error * Apache__DAV__Error;
typedef dav_get_props_result * Apache__DAV__PropsResult;
typedef dav_hooks_db * Apache__DAV__HooksDb;
typedef dav_hooks_liveprop * Apache__DAV__HooksLiveprop;
typedef dav_hooks_locks * Apache__DAV__HooksLocks;
typedef dav_hooks_repository * Apache__DAV__HooksRepository;
typedef dav_if_header * Apache__DAV__IfHeader;
typedef dav_if_state_list * Apache__DAV__StateList;
typedef dav_lock * Apache__DAV__Lock;
typedef dav_lock_rectype * Apache__DAV__LockRectype;
typedef dav_lock_scope * Apache__DAV__LockScope;
typedef dav_lock_type * Apache__DAV__LockType;
typedef dav_lockdb * Apache__DAV__LockDB;
typedef dav_locktoken * Apache__DAV__LockToken;
typedef dav_locktoken_list * Apache__DAV__LockTokenList;
typedef dav_lookup_result * Apache__DAV__LockupResult;
typedef dav_prop_ctx * Apache__DAV__PropCtx;
typedef dav_propdb * Apache__DAV__PropDB;
typedef dav_resource * Apache__DAV__Resource;
typedef dav_resource_type * Apache__DAV__ResourcePrivate;
typedef dav_response * Apache__DAV__Response;
typedef dav_text * Apache__DAV__Text;
typedef dav_text_header * Apache__DAV__TextHeader;
typedef dav_walker_ctx * Apache__DAV__WalkerCtx;
typedef dav_xml_attr * Apache__DAV__XMLAttr;
typedef dav_xml_doc * Apache__DAV__XMLDoc;
typedef dav_xml_elem * Apache__DAV__XMLElem;
typedef pool * Apache__Pool;
typedef request_rec * Apache;
typedef server_rec * Apache__Server;
typedef dav_if_state_type * Apache__DAV__IfStateType;
typedef dav_db * Apache__DAV__Db;
typedef dav_stream * Apache__DAV__Stream;
typedef dav_liveprop_rollback * Apache__DAV__LivepropRollback;
typedef void * PTR;

#ifndef pTHX_
#define pTHX_
#endif
#ifndef aTHX_
#define aTHX_
#endif
#ifndef pTHX
#define pTHX
#endif
#ifndef aTHX
#define aTHX
#endif


#ifndef XSprePUSH
#define XSprePUSH (sp = PL_stack_base + ax - 1)
#endif


#endif /* MODDAV_XS_TYPEDEFS_H */
