# 
# /*
#  * *********** WARNING **************
#  * This file generated by Apache::DAV::WrapXS/0.01
#  * Any changes made here will be lost
#  * ***********************************
#  * 1. /opt/perl5.6.1/lib/site_perl/5.6.1/ExtUtils/XSBuilder/WrapXS.pm:38
#  * 2. /opt/perl5.6.1/lib/site_perl/5.6.1/ExtUtils/XSBuilder/WrapXS.pm:1898
#  * 3. xsbuilder/xs_generate.pl:6
#  */
# 


package Apache::DAV::LockupResult;
require DynaLoader ;
use strict ;
use vars qw{$VERSION @ISA} ;

push @ISA, 'DynaLoader' ;
$VERSION = '0.01';
bootstrap Apache::DAV::LockupResult $VERSION ;



1;
__END__
